==> pyMetaheuristic-1.5.9-py3-none-any.whl: pyMetaheuristic/algorithm/__init__.py <==
from .abco import artificial_bee_colony_optimization
from .afsa import artificial_fish_swarm_algorithm
from .alo import ant_lion_optimizer
from .aoa import arithmetic_optimization_algorithm
from .ars import adaptive_random_search
from .bat_a import bat_algorithm
from .bbo import biogeography_based_optimization
from .cat_so import cat_swarm_optimization
from .cem import cross_entropy_method
from .chicken_so import chicken_swarm_optimization
from .cockroach_so import cockroach_swarm_optimization
from .csa import crow_search_algorithm
from .cuckoo_s import cuckoo_search
from .da import dragonfly_algorithm
from .de import differential_evolution
from .dfo import dispersive_fly_optimization
from .dvba import dynamic_virtual_bats_algorithm
from .eho import elephant_herding_optimization
from .fda import flow_direction_algorithm
from .firefly_a import firefly_algorithm
from .fpa import flower_pollination_algorithm
from .ga import genetic_algorithm
from .goa import grasshopper_optimization_algorithm
from .gsa import gravitational_search_algorithm
from .gwo import grey_wolf_optimizer
from .hho import harris_hawks_optimization
from .hus import hunting_search_algorithm
from .i_gwo import improved_grey_wolf_optimizer
from .i_woa import improved_whale_optimization_algorithm
from .jso import jellyfish_search_optimizer
from .jy import victory
from .kha import krill_herd_algorithm
from .mbo import monarch_butterfly_optimization
from .memetic_a import memetic_algorithm
from .mfa import moth_flame_algorithm
from .mvo import muti_verse_optimizer
from .pfa import pathfinder_algorithm
from .pso import particle_swarm_optimization
from .random_s import random_search
from .sa import simulated_annealing
from .sine_cosine_a import sine_cosine_algorithm
from .sos import symbiotic_organisms_search
from .spbo import student_psychology_based_optimization
from .ssa import salp_swarm_algorithm
from .tlbo import teaching_learning_based_optimization
from .whale_optimization_a import whale_optimization_algorithm

==> pyMetaheuristic-1.9.2-py3-none-any.whl: pyMetaheuristic/algorithm/__init__.py <==
from .abco import artificial_bee_colony_optimization
from .acgwo import adaptive_chaotic_grey_wolf_optimizer
from .afsa import artificial_fish_swarm_algorithm
from .alo import ant_lion_optimizer
from .aoa import arithmetic_optimization_algorithm
from .ars import adaptive_random_search
from .bat_a import bat_algorithm
from .bbo import biogeography_based_optimization
from .ca import cultural_algorithm
from .cat_so import cat_swarm_optimization
from .cem import cross_entropy_method
from .chicken_so import chicken_swarm_optimization
from .clonalg import clonal_selection_algorithm
from .coati_oa import coati_optimization_algorithm
from .cockroach_so import cockroach_swarm_optimization
from .csa import crow_search_algorithm
from .cuckoo_s import cuckoo_search
from .da import dragonfly_algorithm
from .de import differential_evolution
from .dfo import dispersive_fly_optimization
from .dvba import dynamic_virtual_bats_algorithm
from .eho import elephant_herding_optimization
from .fda import flow_direction_algorithm
from .firefly_a import firefly_algorithm
from .fpa import flower_pollination_algorithm
from .ga import genetic_algorithm
from .gmo import geometric_mean_optimizer
from .goa import grasshopper_optimization_algorithm
from .gsa import gravitational_search_algorithm
from .gwo import grey_wolf_optimizer
from .hho import harris_hawks_optimization
from .hsa import harmony_search_algorithm
from .hus import hunting_search_algorithm
from .i_gwo import improved_grey_wolf_optimizer
from .i_woa import improved_whale_optimization_algorithm
from .jso import jellyfish_search_optimizer
from .jy import victory
from .kha import krill_herd_algorithm
from .mbo import monarch_butterfly_optimization
from .memetic_a import memetic_algorithm
from .mfa import moth_flame_algorithm
from .mvo import muti_verse_optimizer
from .pbil import population_based_incremental_learning
from .pfa import pathfinder_algorithm
from .pso import particle_swarm_optimization
from .random_s import random_search
from .sa import simulated_annealing
from .sine_cosine_a import sine_cosine_algorithm
from .sos import symbiotic_organisms_search
from .spbo import student_psychology_based_optimization
from .ssa import salp_swarm_algorithm
from .tlbo import teaching_learning_based_optimization
from .woa import whale_optimization_algorithm
